uv

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 3, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsInstalled

func IsInstalled() bool

IsInstalled checks if uv is installed by running "uv --version"

Types

type InstallResult

type InstallResult struct {
	Installed bool
	Message   string
	Error     error
}

InstallResult represents the result of uv installation

func EnsureInstalled

func EnsureInstalled() InstallResult

EnsureInstalled checks if uv is installed, and installs it if not

func Install

func Install() InstallResult

Install attempts to install uv using the official installer script

Jump to