Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsInstalled ¶
func IsInstalled() bool
IsInstalled checks if uv is installed by running "uv --version"
Types ¶
type InstallResult ¶
InstallResult represents the result of uv installation
func EnsureInstalled ¶
func EnsureInstalled() InstallResult
EnsureInstalled checks if uv is installed, and installs it if not
func Install ¶
func Install() InstallResult
Install attempts to install uv using the official installer script
Click to show internal directories.
Click to hide internal directories.